@@ -4,7 +4,7 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 use Statistics::Frequency 0.04;
 @ISA = qw(Statistics::Frequency);
@@ -198,11 +198,11 @@ L<Statistics::Simpson>
 For the data manipulation interface see (though the whole
 interface is documented here)
 
-L<Statictics::Frequency>
+L<Statistics::Frequency>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2002-2015, Jarkko Hietaniemi <jhi@iki.fi>
+Copyright (C) 2002-2016, Jarkko Hietaniemi <jhi@iki.fi>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl 5.18.2.
